@@ -34,7 +34,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void slotAudioFileChanged(const QString &url);
     void startPlayback();
-    void slotPlaybackFinished(QMediaPlayer::State state);
+    void slotPlaybackFinished(QMediaPlayer::PlaybackState state);
     void startRecordAudio();
     void downloadWebserviceAudio();
     void handleDownloadWebserviceFinished();
