@@ -3,7 +3,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef GENDERBACKENDMODE_H
 #define GENDERBACKENDMODE_H
 
@@ -12,29 +11,26 @@
 
 namespace Practice
 {
-
 class GenderBackendMode : public MultipleChoiceBackendMode
 {
     Q_OBJECT
 
 public:
-    GenderBackendMode(AbstractFrontend *frontend,
-                      QObject *parent, Practice::SessionManagerBase* sessionManager,
-                      KEduVocDocument* doc);
+    GenderBackendMode(AbstractFrontend *frontend, QObject *parent, Practice::SessionManagerBase *sessionManager, KEduVocDocument *doc);
 
     /** Start practicing a new word */
-    bool setTestEntry(TestEntry* current) Q_DECL_OVERRIDE;
+    bool setTestEntry(TestEntry *current) override;
 
-    grade_t currentPreGradeForEntry() const Q_DECL_OVERRIDE;
-    grade_t currentGradeForEntry() const Q_DECL_OVERRIDE;
+    grade_t currentPreGradeForEntry() const override;
+    grade_t currentGradeForEntry() const override;
 
 protected:
-    void prepareChoices(TestEntry* current) Q_DECL_OVERRIDE;
-    void updateGrades() Q_DECL_OVERRIDE;
+    void prepareChoices(TestEntry *current) override;
+    void updateGrades() override;
 
 private:
     /** Reference to the kvocdoc */
-    const KEduVocDocument & m_doc;
+    const KEduVocDocument &m_doc;
     KEduVocArticle m_articles;
     QString m_masculine;
     QString m_feminine;
